@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.2 2001/03/04 14:07:48 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.3 2001/03/09 17:11:21 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -55,7 +55,7 @@ bool Resources::Application::load (xmlDocPtr doc,
 	    xml_iconname = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
 	else if (!strcmp ((char*)curr_node->name, "version") && !xml_version)
 	    xml_version = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
-	else if (!strcmp ((char*)curr_node->name, "vendor") && !xml_version)
+	else if (!strcmp ((char*)curr_node->name, "vendor") && !xml_vendor)
 	    xml_vendor = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
 	else
 	    g_warning ("Error parsing `application' resource: "
