@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.5 2001/03/04 14:07:48 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.7 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,12 +24,13 @@
 #include <gtk--/menu.h>
 #include <gnome--/dialog.h>
 #include <sigc++/retbind.h>
+#include "resource-combo.h"
 
 using namespace Guikachu;
 
 GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
     res (res_),
-    help_res (0),
+    help_combo (Resources::RESOURCE_STRING),
     update_block (true)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
@@ -45,9 +46,7 @@ GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
     title_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "dialog_title")));
     text_entry = wrap (GTK_TEXT (glade_xml_get_widget (gui, "dialog_text")));
     type_combo = wrap (GTK_OPTION_MENU (glade_xml_get_widget (gui, "dialog_type")));
-    help_combo = wrap (GTK_COMBO (glade_xml_get_widget (gui, "dialog_help")));
-    btnHelpEdit = wrap (GTK_BUTTON (glade_xml_get_widget (gui, "dialog_help_edit")));
-    
+
     text_entry->set_word_wrap (true);
 
     // Set up callbacks
@@ -63,7 +62,7 @@ GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
 
     text_entry->changed.connect (slot (this, &DialogWindow::text_entry_cb));
 
-    btnHelpEdit->clicked.connect (slot (this, &DialogWindow::help_edit_cb));
+    help_combo.changed.connect (slot (this, &DialogWindow::help_combo_cb));
     
     // Dialog type dropdown
     Menu *type_menu = new Menu ();
@@ -85,27 +84,10 @@ GUI::DialogWindow::DialogWindow (Guikachu::Resources::Dialog *res_):
     type_menu->show_all ();
     type_combo->set_menu (*manage (type_menu));
 
-    // Fill the Help ID combo list
-    set<Resources::Resource*> resource_set = ResourceManager::get_resources ();
-    vector<string> help_list;
-    help_list.push_back ("");
-    for (set<Resources::Resource*>::iterator i = resource_set.begin ();
-	 i != resource_set.end (); i++)
-    {
-	if ((*i)->get_type () == Resources::RESOURCE_STRING)
-	{
-	    help_list.push_back ((*i)->get_id ());
-	    (*i)->changed.connect (bind (
-		slot (this, &DialogWindow::help_res_changed_cb),
-		(*i)));
-	}
-    }
-    help_combo->set_popdown_strings (help_list);
-
-    ResourceManager::resource_created.connect (slot (this, &DialogWindow::resource_created_cb));
-    ResourceManager::resource_removed.connect (slot (this, &DialogWindow::resource_removed_cb));
-    help_combo->get_entry ()->changed.connect (slot (this, &DialogWindow::help_combo_cb));
-
+    Gtk::Container *help_place;
+    help_place = wrap (GTK_CONTAINER (glade_xml_get_widget (gui, "dialog_help_place")));
+    help_place->add (help_combo);
+    
     // Widgets for page 2
     button_list = wrap (GTK_LIST (glade_xml_get_widget (gui, "dialog_buttonlist")));
     button_list->selection_changed.connect (slot (this, &DialogWindow::button_sel_change_cb));
@@ -134,7 +116,7 @@ GUI::DialogWindow::~DialogWindow ()
 
 void GUI::DialogWindow::show ()
 {
-    window->show ();
+    window->show_all ();
     window->get_window ().raise ();
 }
 
@@ -144,73 +126,6 @@ int GUI::DialogWindow::delete_event_impl (GdkEventAny *e)
     return true;
 }
 
-void GUI::DialogWindow::resource_created_cb (Resources::Resource *new_res)
-{
-    if (new_res->get_type () != Resources::RESOURCE_STRING)
-	return;
-
-    update_block = true;
-
-    Gtk::ListItem *item = new Gtk::ListItem (new_res->get_id ());
-    item->set_user_data (new_res);
-    item->show ();
-    help_combo->get_list ()->add (*manage (item));
-    help_combo->get_entry ()->set_text (res->get_help_id ());
-
-    if (new_res->get_id () == res->get_help_id ())
-	    help_res = new_res;
-
-    new_res->changed.connect (bind (
-	slot (this, &DialogWindow::help_res_changed_cb),
-	new_res));
-    
-    update_block = false;
-}
-
-void GUI::DialogWindow::resource_removed_cb (Resources::Resource *help_res)
-{
-    if (help_res->get_type () != Resources::RESOURCE_STRING)
-	return;
-
-    update_block = true;
-
-    set<Resources::Resource*> resource_set = ResourceManager::get_resources ();
-    vector<string> help_list;
-    for (set<Resources::Resource*>::iterator i = resource_set.begin ();
-	 i != resource_set.end (); i++)
-    {
-	if ((*i)->get_type () == Resources::RESOURCE_STRING &&
-	    (*i) != help_res)
-	    help_list.push_back ((*i)->get_id ());
-    }
-    help_combo->set_popdown_strings (help_list);
-    
-    update_block = false;
-
-    if (help_res->get_id () == res->get_help_id ())
-	res->set_help_id ("");
-}
-
-void GUI::DialogWindow::help_res_changed_cb (Resources::Resource *changed_res)
-{
-    if (changed_res == help_res)
-	res->set_help_id (help_res->get_id ());
-
-    update_block = true;
-    using namespace Gtk::List_Helpers;
-
-    ItemList& itemlist = help_combo->get_list ()->items ();
-    ItemList::iterator i = itemlist.begin ();
-    while (i != itemlist.end () && (*i)->get_user_data () != changed_res)
-	i++;
-    g_return_if_fail (i != itemlist.end ());
-
-    (*i)->remove ();
-    (*i)->add_label (changed_res->get_id ());
-    
-    update_block = false;
-}
-
 void GUI::DialogWindow::update ()
 {
     gchar *title_buf = g_strdup_printf (_("Dialog: %s"), res->get_id ().c_str ());
@@ -227,14 +142,7 @@ void GUI::DialogWindow::update ()
     text_entry->insert (res->get_text ());
 
     type_combo->set_history (res->get_dialog_type ());
-    help_combo->get_entry ()->set_text (res->get_help_id ());
-    help_res = ResourceManager::get_resource (res->get_help_id ());
-
-    if (help_res)
-	btnHelpEdit->set_sensitive (true);
-    else
-	btnHelpEdit->set_sensitive (false);
-
+    help_combo.set_value (res->get_help_id ());
     
     vector<string> buttons = res->get_buttons ();
     vector<string>::iterator i;
@@ -285,19 +193,12 @@ void GUI::DialogWindow::type_menu_cb (Resources::DialogType type)
     res->set_dialog_type (type);
 }
 
-void GUI::DialogWindow::help_combo_cb ()
+void GUI::DialogWindow::help_combo_cb (const string& help_id)
 {
     if (update_block)
 	return;
 
-    res->set_help_id (help_combo->get_entry ()->get_text ());
-}
-
-void GUI::DialogWindow::help_edit_cb ()
-{
-    g_return_if_fail (help_res != NULL);
-
-    help_res->show_ui ();
+    res->set_help_id (help_id);
 }
 
 void GUI::DialogWindow::dialog_add_cb (string name)
