@@ -1,4 +1,4 @@
-//$Id: dialog-win.h,v 1.4 2001/03/04 14:07:48 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.h,v 1.6 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,7 +35,7 @@ namespace Guikachu
 #include <gtk--/optionmenu.h>
 #include <gtk--/button.h>
 #include <gtk--/list.h>
-#include <gtk--/combo.h>
+#include "resource-combo.h"
 
 #include <glade/glade-xml.h>
 
@@ -46,20 +46,18 @@ namespace Guikachu
 	class DialogWindow: public SigC::Object
 	{
 	    Resources::Dialog   *res;
-	    Resources::Resource *help_res;
 	    
-	    GladeXML          *gui;
-	    Gtk::Window       *window;
+	    GladeXML            *gui;
+	    Gtk::Window         *window;
 	    
-	    Gtk::Entry        *id_entry;
-	    Gtk::Entry        *title_entry;
-	    Gtk::Text         *text_entry;
-	    Gtk::OptionMenu   *type_combo;
-	    Gtk::Combo        *help_combo;
-	    Gtk::Button       *btnHelpEdit;
+	    Gtk::Entry          *id_entry;
+	    Gtk::Entry          *title_entry;
+	    Gtk::Text           *text_entry;
+	    Gtk::OptionMenu     *type_combo;
+	    GUI::ResourceCombo   help_combo;
 	    
-	    Gtk::List         *button_list;
-	    Gtk::Button       *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
+	    Gtk::List           *button_list;
+	    Gtk::Button         *btnUp, *btnDown, *btnRemove, *btnAdd, *btnDefault;
 	public:
 	    DialogWindow (Resources::Dialog *res_);
 	    ~DialogWindow ();
@@ -68,17 +66,11 @@ namespace Guikachu
 	    int delete_event_impl (GdkEventAny *e);
 	    void update ();
 
-	    void resource_created_cb (Resources::Resource *new_res);
-	    void resource_removed_cb (Resources::Resource *help_res);
-	    SigC::Connection help_res_changed_conn;
-	    void help_res_changed_cb (Resources::Resource *changed_res);
-	    
 	    void id_entry_cb (GdkEventFocus *e);
 	    void title_entry_cb (GdkEventFocus *e);
 	    void text_entry_cb ();
 	    void type_menu_cb (Resources::DialogType type);
-	    void help_combo_cb ();
-	    void help_edit_cb ();
+	    void help_combo_cb (const string& help_id);
 	    bool update_block;
 
 	    void button_add_cb ();
