@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.1 2001/02/18 14:29:22 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.2 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <glade/glade.h>
 
 #include "mainwin.h"
+#include "resource-manager.h"
 
 int main (int argc, char **argv)
 {
@@ -33,6 +34,7 @@ int main (int argc, char **argv)
     Gnome::Main m (PACKAGE, VERSION, argc, argv);
     glade_gnome_init ();
 
+    Guikachu::ResourceManager::reset ();
     Guikachu::GUI::MainWin w;
 
     w.show_all ();
