@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.5 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.8 2001/03/24 11:50:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -56,13 +56,13 @@ GUI::MainWin::MainWin ():
     /* File menu */
     list <UI::Info> m_file;
 
-    m_file.push_back (MenuItems::New    (_("New project"), _("Create a new project"),
+    m_file.push_back (MenuItems::New    (_("_New project"), _("Create a new project"),
 					 slot (this, &MainWin::new_cb)));
     m_file.push_back (MenuItems::Open   (slot (this, &MainWin::load_cb)));
     m_file.push_back (MenuItems::Save   (slot (this, &MainWin::save_cb)));
     m_file.push_back (MenuItems::SaveAs (slot (this, &MainWin::save_as_cb)));
     m_file.push_back (UI::Item          (UI::Icon (GNOME_STOCK_PIXMAP_CONVERT),
-					 _("Export RCP..."),
+					 _("Export _RCP..."),
 					 slot (this, &MainWin::export_cb),
 					 _("Create an RCP file for compilation")));
     m_file.push_back (UI::Separator     ());
@@ -107,10 +107,15 @@ GUI::MainWin::MainWin ():
     top_item->show ();
     top_tree->tree ().push_back (*manage (top_item));
     top_item->set_subtree (*manage (main_tree));
-    top_item->expand ();
-    set_contents (*manage (top_tree));
-    
-    set_usize (300, 300);
+    top_item->expand ();    
+
+    // Scrollable viewport
+    Gtk::ScrolledWindow *scrollwin = new Gtk::ScrolledWindow ();
+    scrollwin->set_policy (GTK_POLICY_AUTOMATIC,
+			   GTK_POLICY_AUTOMATIC);
+    scrollwin->add_with_viewport (*manage (top_tree));
+    set_contents (*manage (scrollwin));
+    set_usize (300, 250);
 
     /* Create subtrees */
     create_tree_for_type (Resources::RESOURCE_DIALOG, _("Dialogs"));
@@ -135,6 +140,7 @@ void GUI::MainWin::resource_created_cb (Resources::Resource *resource)
     if (!subtree_item->get_subtree ())
     {
 	subtree_item->set_subtree (*manage (new Gtk::Tree ()));
+	subtree_item->expand ();
     }
     
     subtree_item->get_subtree ()->tree ().push_back (*manage (item));
