@@ -1,4 +1,4 @@
-//$Id: menu-res.cc,v 1.3 2001/02/25 19:10:11 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.4 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -227,5 +227,6 @@ void Menu::save_rcp (ostream &ostr) const
 	ostr << "  END" << endl;
     }
     
-    ostr << "END" << endl;
+    ostr << "END" << endl
+	 << endl;
 }
