@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.5 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.6 2001/03/24 11:50:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -408,11 +408,13 @@ void GUI::MenuWindow::btn_submenu_cb ()
 {
     if (clist->selection ().size () == 0)
     {
-	Resources::Submenu submenu ("New submenu");
+	Resources::Submenu submenu (_("New submenu"));
 	submenus.push_back (submenu);
 
 	res->set_submenus (submenus);
 
+	item_label->grab_focus ();
+
 	return;
     }
 
@@ -421,19 +423,33 @@ void GUI::MenuWindow::btn_submenu_cb ()
     unsigned int row = clist->selection ().begin ()->get_row_num ();
     unsigned int index = clist_rows[row].index;
     vector<Resources::Submenu>::iterator new_index;
-    Resources::Submenu submenu ("New submenu");
+    Resources::Submenu submenu (_("New submenu"));
+    int new_row;
     
     if (clist_rows[row].is_submenu)
     {
-	new_index = submenus.begin () + index + 1;
+	new_index = submenus.begin () + index;
+	new_row = row;
     } else {
 	new_index = submenus.begin () + clist_rows[row].parent_index + 1;
+
+	cout << "row\t\t" << row << endl;
+	cout << "index\t\t" << index << endl;
+	cout << "parent_index\t" << clist_rows[row].parent_index << endl;
+	cout << "parent_size\t" <<
+	    submenus[clist_rows[row].parent_index].items.size () << endl;
+	
+	new_row = row - index +
+	    submenus[clist_rows[row].parent_index].items.size ();
     }
 
     submenus.insert (new_index, submenu);
     
+    clist->select_row (new_row);
     res->set_submenus (submenus);
-    
+    clist->select_row (new_row);
+
+    item_label->grab_focus ();
 }
 
 void GUI::MenuWindow::btn_item_cb (bool separator)
@@ -444,6 +460,7 @@ void GUI::MenuWindow::btn_item_cb (bool separator)
     unsigned int index = clist_rows[row].index;
     unsigned int parent_index = clist_rows[row].parent_index;
     vector<Resources::MenuItem>::iterator pos;
+    unsigned int new_row;
     
     Resources::MenuItem menuitem;
     menuitem.separator = separator;
@@ -457,14 +474,19 @@ void GUI::MenuWindow::btn_item_cb (bool separator)
     
     if (clist_rows[row].is_submenu)
     {
-	pos = submenus[index].items.begin ();	
+	pos = submenus[index].items.end ();	
 	submenus[index].items.insert (pos, menuitem);
+	new_row = row + submenus[index].items.size ();
 	
     } else {
 	
-	pos = submenus[parent_index].items.begin () + index + 1;
+	pos = submenus[parent_index].items.begin () + index;
 	submenus[parent_index].items.insert (pos, menuitem);
+	new_row = row;
     }
-    
-    res->set_submenus (submenus);    
+
+    clist->select_row (new_row);
+    res->set_submenus (submenus);
+
+    item_id->grab_focus ();
 }
