@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.4 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.8 2001/03/23 17:34:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,7 +18,11 @@
 
 #include "resource-manager.h"
 
+#include "config.h"
+#include <libgnome/libgnome.h>
+
 #include <fstream>
+#include <time.h>
 #include <gnome-xml/parser.h>
 
 #include "mainwin.h"
@@ -50,11 +54,27 @@ void ResourceManager::load (const string& filename)
     xmlNodePtr root_node, curr_node;
 
     doc = xmlParseFile (filename.c_str ());
+
+    if (!doc)
+    {
+	gchar *buffer = g_strdup_printf (_("Unable to open `%s'"),
+					 filename.c_str ());
+	GUI::show_error (buffer);
+	g_free (buffer);
+
+	return;
+    }
+	
     root_node = xmlDocGetRootElement (doc);
     
     if (strcmp ((char*)root_node->name, "guikachu"))
     {
-        GUI::show_error ("Document of the wrong type, root node != guikachu\n");
+	gchar *buffer = g_strdup_printf (_("Unable to open `%s': "
+					   "Not a valid Guikachu document"),
+					 filename.c_str ());
+	GUI::show_error (buffer);
+	g_free (buffer);
+
         xmlFreeDoc(doc);
         return;
     }
@@ -84,14 +104,19 @@ Resources::Resource* ResourceManager::load_resource (xmlDocPtr doc,
     char *id = (char*)xmlGetProp (node, (xmlChar*)"id");
 
     if (!id)
+    {
+	g_warning ("`%s': Missing ID field", node_name);
 	return NULL;
+    }
 
-    if (!strcmp (node_name, "string"))
-	resource = create_resource (Resources::RESOURCE_STRING, id);
-    else if (!strcmp (node_name, "dialog"))
+    if (!strcmp (node_name, "dialog"))
 	resource = create_resource (Resources::RESOURCE_DIALOG, id);
+    else if (!strcmp (node_name, "form"))
+	resource = create_resource (Resources::RESOURCE_FORM, id);
     else if (!strcmp (node_name, "menu"))
 	resource = create_resource (Resources::RESOURCE_MENU, id);
+    else if (!strcmp (node_name, "string"))
+	resource = create_resource (Resources::RESOURCE_STRING, id);
     else
 	g_warning ("Unknown resource type `%s'", node_name);
 
@@ -150,6 +175,14 @@ void ResourceManager::export_rcp (const string& filename)
 {
     ofstream fout (filename.c_str ());
 
+    time_t curr_date = time (0);
+    const char* date_str = ctime (&curr_date);
+    
+    fout << "/*" << endl;
+    fout << " * This file was created by Guikachu. Do not edit it  manually" << endl;
+    fout << " * Creation date: " << date_str; // ctime ()'s return value ends in \n
+    fout << " */" << endl << endl;;
+    
     fout << app;
     
     for (map<string_case, Resources::Resource*>::iterator i = resource_map.begin ();
