@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.5 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.6 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,9 +20,10 @@
 
 #include "mainwin.h"
 
-#include "string-res.h"
 #include "dialog-res.h"
+#include "form-res.h"
 #include "menu-res.h"
+#include "string-res.h"
 
 #include <fstream>
 #include <gnome-xml/parser.h>
@@ -102,7 +103,7 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type type,
 	res = new Resources::Menu (id);
 	break;
     case Resources::RESOURCE_FORM:
-	// FIXME: Implement me
+	res = new Resources::Form (id);
 	break;
     }
     
