@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.3 2001/02/24 16:04:14 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.6 2001/03/18 14:18:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,8 +21,15 @@
 
 #include <string>
 #include <iostream>
-#include <gtk--/window.h>
 #include <gnome-xml/tree.h>
+#include <sigc++/basic_signal.h>
+
+#define GUIKACHU_RESOURCE_PROP(param,type)			\
+	private:						\
+	    type param;						\
+	public:							\
+	    type get_##param () const { return param; };	\
+	    void set_##param (const type & param##_) { param = param##_; changed (); };
 
 namespace Guikachu
 {
