@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.2 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.3 2001/03/11 14:14:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,18 +36,15 @@ namespace Guikachu
     {
 	class String: public Resource
 	{
-	    string text;
-
 	    GUI::StringWindow *gui;
 	public:
 	    String (const string& name_);
 	    virtual ~String ();
-	    
+
 	    virtual Type get_type () const { return RESOURCE_STRING; };
 	    virtual void show_ui ();
 
-	    string get_text () { return text; };
-	    void set_text (const string& text_) { text = text_; changed (); };
+	    GUIKACHU_RESOURCE_PROP (text, string);
 
 	private:
 	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
