@@ -1,4 +1,4 @@
-//$Id: treeitem.cc,v 1.3 2001/02/28 20:11:43 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.cc,v 1.4 2001/03/06 18:25:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,18 +32,41 @@ GUI::TreeItem::TreeItem (Resources::Resource *res_):
     Gtk::TreeItem (res_->get_id ()),
     res (res_)
 {
-    button_press_event.connect (slot (this, &GUI::TreeItem::clicked_cb));
+    button_press_event.connect (slot (this, &GUI::TreeItem::button_press_cb));
+    key_press_event.connect (slot (this, &GUI::TreeItem::key_press_cb));
+    
     res->changed.connect (slot (this, &GUI::TreeItem::resource_changed_cb));
-
+    
     list <UI::Info> popup_menu_list;
     popup_menu_list.push_back (
 	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
 		  _("Remove"),
-		  SigC::slot (this, &GUI::TreeItem::menu_remove_cb)));
+		  SigC::slot (this, &GUI::TreeItem::remove_cb)));
     UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
 }
 
-int GUI::TreeItem::clicked_cb (GdkEventButton *e)
+int GUI::TreeItem::key_press_cb (GdkEventKey *e)
+{
+    switch (e->keyval)
+    {
+    case GDK_Return:
+    case GDK_KP_Enter:
+	res->show_ui ();
+	break;
+	
+    case GDK_Delete:
+    case GDK_KP_Delete:	
+	remove_cb ();
+	break;
+
+    default:
+	break;
+    }
+
+    return true;
+}
+
+int GUI::TreeItem::button_press_cb (GdkEventButton *e)
 {
     if (e->type == GDK_2BUTTON_PRESS && e->button == 1)
 	res->show_ui ();
@@ -61,7 +84,7 @@ void GUI::TreeItem::resource_changed_cb ()
     add_label (res->get_id ());
 }
 
-void GUI::TreeItem::menu_remove_cb ()
+void GUI::TreeItem::remove_cb ()
 {
     ResourceManager::remove_resource (res);
 }
